import pygame
import random
import time
import os

# Initialiseren van pygame
pygame.init()

# Kleuren
WIT = (255, 255, 255)
ZWART = (0, 0, 0)
GRIJS = (200, 200, 200)
ACHTERGROND_KLEUR = (173, 216, 230)  # Lichtblauw
KAART_KLEUREN = [(255, 0, 0), (0, 255, 0), (0, 0, 255), (255, 255, 0), (255, 165, 0), (128, 0, 128), (0, 255, 255), (255, 192, 203)]

# Afmetingen van het scherm en kaarten
SCHERM_BREEDTE = 400
SCHERM_HOOGTE = 400
KAART_BREEDTE = 100
KAART_HOOGTE = 100

# Kaartsymbolen als afbeeldingen
aantal_kaarten = 10  # Aantal unieke kaarten
symbolen = [f"{i+1}.jpg" for i in range(aantal_kaarten)]

def maak_bord(rijen, kolommen):
    paren = (rijen * kolommen) // 2
    symbolen_set = symbolen[:paren] * 2
    random.shuffle(symbolen_set)
    bord = [[None for _ in range(kolommen)] for _ in range(rijen)]
    for i in range(rijen):
        for j in range(kolommen):
            bord[i][j] = symbolen_set.pop()
    return bord

def teken_bord(scherm, bord, onthuld, gevonden):
    scherm.fill(ACHTERGROND_KLEUR)
    for i in range(len(bord)):
        for j in range(len(bord[0])):
            x = j * KAART_BREEDTE
            y = i * KAART_HOOGTE
            if (i, j) in onthuld or (i, j) in gevonden:
                if (i, j) in gevonden:
                    pygame.draw.rect(scherm, random.choice(KAART_KLEUREN), (x, y, KAART_BREEDTE, KAART_HOOGTE))
                else:
                    pygame.draw.rect(scherm, GRIJS, (x, y, KAART_BREEDTE, KAART_HOOGTE))
                try:
                    print(bord[i][j])
                    print(os.getcwd())
                    afbeelding = pygame.image.load(f"{bord[i][j]}")
                    afbeelding = pygame.transform.scale(afbeelding, (KAART_BREEDTE, KAART_HOOGTE))
                    scherm.blit(afbeelding, (x, y))
                except pygame.error:
                    print(f"Afbeelding niet gevonden: {bord[i][j]}")
            else:
                pygame.draw.rect(scherm, ZWART, (x, y, KAART_BREEDTE, KAART_HOOGTE))
    pygame.display.flip()

def teken_start_scherm(scherm):
    scherm.fill(ACHTERGROND_KLEUR)
    font = pygame.font.Font(None, 74)
    tekst = font.render("Memory Spel", True, ZWART)
    tekst_rect = tekst.get_rect(center=(SCHERM_BREEDTE // 2, SCHERM_HOOGTE // 3))
    scherm.blit(tekst, tekst_rect)
    
    font = pygame.font.Font(None, 36)
    start_tekst = font.render("Start", True, WIT)
    start_rect = pygame.Rect((SCHERM_BREEDTE // 2 - 50, SCHERM_HOOGTE // 2 - 25), (100, 50))
    pygame.draw.rect(scherm, ZWART, start_rect)
    scherm.blit(start_tekst, (start_rect.x + 20, start_rect.y + 10))
    
    pygame.display.flip()
    return start_rect

def animatie_vind(scherm, kaarten):
    for _ in range(5):
        kleur = random.choice(KAART_KLEUREN)
        for kaart in kaarten:
            pygame.draw.rect(scherm, kleur, (kaart[1] * KAART_BREEDTE, kaart[0] * KAART_HOOGTE, KAART_BREEDTE, KAART_HOOGTE))
        pygame.display.flip()
        time.sleep(0.1)

def main():
    scherm = pygame.display.set_mode((SCHERM_BREEDTE, SCHERM_HOOGTE))
    pygame.display.set_caption("Memory Spel")
    klok = pygame.time.Clock()
    
    start_rect = teken_start_scherm(scherm)
    spel_gestart = False

    while not spel_gestart:
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                return
            elif event.type == pygame.MOUSEBUTTONDOWN:
                x, y = pygame.mouse.get_pos()
                if start_rect.collidepoint(x, y):
                    spel_gestart = True

    rijen = 4
    kolommen = 4
    bord = maak_bord(rijen, kolommen)
    onthuld = set()
    gevonden = set()
    paren = (rijen * kolommen) // 2
    omgedraaide_kaarten = []

    while len(gevonden) < paren:
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                return
            elif event.type == pygame.MOUSEBUTTONDOWN and len(omgedraaide_kaarten) < 2:
                x, y = pygame.mouse.get_pos()
                kol = x // KAART_BREEDTE
                rij = y // KAART_HOOGTE
                if (rij, kol) not in onthuld and (rij, kol) not in omgedraaide_kaarten:
                    omgedraaide_kaarten.append((rij, kol))
                    onthuld.add((rij, kol))

        teken_bord(scherm, bord, onthuld, gevonden)
        if len(omgedraaide_kaarten) == 2:
            pygame.display.flip()
            time.sleep(1)
            if bord[omgedraaide_kaarten[0][0]][omgedraaide_kaarten[0][1]] == bord[omgedraaide_kaarten[1][0]][omgedraaide_kaarten[1][1]]:
                gevonden.add(omgedraaide_kaarten[0])
                # gevonden.add(omgedraaide_kaarten)
                animatie_vind(scherm, omgedraaide_kaarten)
            else:
                onthuld.difference_update(omgedraaide_kaarten)
            omgedraaide_kaarten = []

        klok.tick(30)

    print("Gefeliciteerd! Je hebt alle paren gevonden.")
    pygame.quit()

if __name__ == "__main__":
    main()

